==> icedove-dispmua_1.6.3.orig.tar.gz: icedove-dispmua-1.6.3/chrome/content/data-6b.js <==
dispMUA.arDispMUAAllocation["k"] =
{
  "kayako supportsuite" : [ "kayako.png" , "http://www.kayako.com/" ] ,
  "kerio mailserver" : [ "kerio.png" , "http://www.kerio.eu/" ] ,
  "kochmeister.com" : [ "kochmeister.png" , "http://www.kochmeister.com/" ] ,
  "knowledgemarket" : [ "realcom.png" , "http://www.realcom.co.jp/software/knowledgemarket_index.html" ] ,
  "kayako esupport" : [ "kayako.png" , "http://www.kayako.com/" ] ,
  "konica minolta" : [ "konica-minolta.png" , "http://www.konicaminolta.com/" ] ,
  "kaufman pravda" : [ "kaufman_pravda.png" , "http://www.kaufmansoft.com/" ] ,
  "karen's mailer" : [ "karensmailer.png" , "http://www.karenware.com/" ] ,
  "kontur-extern" : [ "kontur-extern.png" , "http://www.kontur-extern.ru/" ] ,
  "kienis mailer" : [ "kienis_mailer.png" ] ,
  "kerio outlook" : [ "kerio.png" , "http://www.kerio.eu/" ] ,
  "kelare module" : [ "kelare.png" , "http://www.kelare.com/index.ks?page=extensions_notemail" ] ,
  "kana response" : [ "kana.png" , "http://www.kana.com/" ] ,
  "kajomimail" : [ "kajomi.png" , "http://www.kajomi.de/" ] ,
  "kurinnaxx" : [ "kurinnaxx.png" ] ,
  "kronolith" : [ "horde.png" , "http://www.horde.org/kronolith/" ] ,
  "kopiemail" : [ "kopiemail.png" , "http://www.pi-sync.net/" ] ,
  "koma-mail" : [ "koma_mail.png" , "http://www.koma-code.de/" ] ,
  "kolbaskin" : [ "kolbaskin.png" , "http://habrahabr.ru/" ] ,
  "knallhart" : [ "knallhart.png" , "http://www.knallhart.de/" ] ,
  "kaspersky" : [ "kaspersky.png" , "http://www.kaspersky.com/" ] ,
  "kronodoc" : [ "kronodoc.png" , "http://www.kronodoc.com/" ] ,
  "katamail" : [ "katamail.png" , "http://www.katamail.kataweb.it/" ] ,
  "kamailv3" : [ "kamail.png" , "http://www7a.biglobe.ne.jp/~hat/xyzzy/kamail3.html" ] ,
  "koomail" : [ "koomail.png" , "http://www.koomail.com/" ] ,
  "kjmmail" : [ "kajomi.png" , "http://www.kajomi.de/" ] ,
  "komnex" : [ "komnex.png" , "http://www.komnex.de/" ] ,
  "kamail" : [ "kamail.png" , "http://www7a.biglobe.ne.jp/~hat/xyzzy/kamail.html" ] ,
  "k-mail" : [ "k-mail.png" , "http://www.kcsoftwares.com/" ] ,
  "knode" : [ "knode.png" , "http://www.pi-sync.net/" ] ,
  "knews" : [ "knews.png" , "http://www.matematik.su.se/users/kjj/knews.html" ] ,
  "kmail" : [ "kmail.png" , "http://kontact.kde.org/kmail/" ] ,
  "kiala" : [ "kiala.png" , "http://www.kiala.com/" ] ,
  "kenm3" : [ "kenm3.png" , "http://www.bekkoame.ne.jp/~adeus/download.htm" ] ,
  "ken!" : [ "ken.png" , "http://www.avm.de/" ] ,
  "kana" : [ "kana.png" , "http://www.kana.com/" ] ,
}

==> icedove-dispmua_1.6.4.3.orig.tar.gz: icedove-dispmua-1.6.4.3/chrome/content/data-6b.js <==
dispMUA.arDispMUAAllocation["k"] =
{
  "kayako supportsuite" : [ "kayako.png" , "http://www.kayako.com/" ] ,
  "kerio mailserver" : [ "kerio.png" , "http://www.kerio.eu/" ] ,
  "kochmeister.com" : [ "kochmeister.png" , "http://www.kochmeister.com/" ] ,
  "knowledgemarket" : [ "realcom.png" , "http://www.realcom.co.jp/software/knowledgemarket_index.html" ] ,
  "kayako esupport" : [ "kayako.png" , "http://www.kayako.com/" ] ,
  "konica minolta" : [ "konica-minolta.png" , "http://www.konicaminolta.com/" ] ,
  "kaufman pravda" : [ "kaufman_pravda.png" , "http://www.kaufmansoft.com/" ] ,
  "karen's mailer" : [ "karensmailer.png" , "http://www.karenware.com/" ] ,
  "kontur-extern" : [ "kontur-extern.png" , "http://www.kontur-extern.ru/" ] ,
  "kienis mailer" : [ "kienis_mailer.png" ] ,
  "kerio outlook" : [ "kerio.png" , "http://www.kerio.eu/" ] ,
  "kelare module" : [ "kelare.png" , "http://www.kelare.com/index.ks?page=extensions_notemail" ] ,
  "kana response" : [ "kana.png" , "http://www.kana.com/" ] ,
  "kfj-mailer" : [ "kunstfuerjedermann.png" , "http://www.kunstfuerjedermann.com/" ] ,
  "kajomimail" : [ "kajomi.png" , "http://www.kajomi.de/" ] ,
  "kurinnaxx" : [ "kurinnaxx.png" ] ,
  "kronolith" : [ "horde.png" , "http://www.horde.org/kronolith/" ] ,
  "kopiemail" : [ "kopiemail.png" , "http://www.pi-sync.net/" ] ,
  "koma-mail" : [ "koma_mail.png" , "http://www.koma-code.de/" ] ,
  "kolbaskin" : [ "kolbaskin.png" , "http://habrahabr.ru/" ] ,
  "knallhart" : [ "knallhart.png" , "http://www.knallhart.de/" ] ,
  "kaspersky" : [ "kaspersky.png" , "http://www.kaspersky.com/" ] ,
  "kuborgh*" : [ "kuborgh.png" , "http://www.kuborgh.de/" ] ,
  "kronodoc" : [ "kronodoc.png" , "http://www.kronodoc.com/" ] ,
  "katamail" : [ "katamail.png" , "http://www.katamail.kataweb.it/" ] ,
  "kamailv3" : [ "kamail.png" , "http://www7a.biglobe.ne.jp/~hat/xyzzy/kamail3.html" ] ,
  "koomail" : [ "koomail.png" , "http://www.koomail.com/" ] ,
  "kjmmail" : [ "kajomi.png" , "http://www.kajomi.de/" ] ,
  "komnex" : [ "komnex.png" , "http://www.komnex.de/" ] ,
  "kamail" : [ "kamail.png" , "http://www7a.biglobe.ne.jp/~hat/xyzzy/kamail.html" ] ,
  "k-mail" : [ "k-mail.png" , "http://www.kcsoftwares.com/" ] ,
  "knode" : [ "knode.png" , "http://www.pi-sync.net/" ] ,
  "knews" : [ "knews.png" , "http://www.matematik.su.se/users/kjj/knews.html" ] ,
  "kmail" : [ "kmail.png" , "http://kontact.kde.org/kmail/" ] ,
  "kiala" : [ "kiala.png" , "http://www.kiala.com/" ] ,
  "khxc/" : [ "kryptronic_com.png" , "http://www.kryptronic.com/" ] ,
  "kenm3" : [ "kenm3.png" , "http://www.bekkoame.ne.jp/~adeus/download.htm" ] ,
  "ken!" : [ "ken.png" , "http://www.avm.de/" ] ,
  "kana" : [ "kana.png" , "http://www.kana.com/" ] ,
}
